Documentation
¶
Index ¶
- Variables
- type ClientDetails
- func (*ClientDetails) Descriptor() ([]byte, []int)deprecated
- func (x *ClientDetails) GetAgent() *wrapperspb.StringValue
- func (x *ClientDetails) GetArch() *wrapperspb.StringValue
- func (x *ClientDetails) GetChannel() *wrapperspb.StringValue
- func (x *ClientDetails) GetOs() *wrapperspb.StringValue
- func (x *ClientDetails) GetProtocolVersion() *wrapperspb.StringValue
- func (x *ClientDetails) GetToken() *wrapperspb.StringValue
- func (x *ClientDetails) GetVersion() *wrapperspb.StringValue
- func (*ClientDetails) ProtoMessage()
- func (x *ClientDetails) ProtoReflect() protoreflect.Message
- func (x *ClientDetails) Reset()
- func (x *ClientDetails) String() string
- type CloseControlChannelReq
- type CloseControlChannelRsp
- type CloseTunnelReq
- type CloseTunnelRsp
- type Error
- type ErrorCode
- type Heartbeat
- type IpAddress
- func (*IpAddress) Descriptor() ([]byte, []int)deprecated
- func (x *IpAddress) GetAddr() isIpAddress_Addr
- func (x *IpAddress) GetV4() uint32
- func (x *IpAddress) GetV6() []byte
- func (*IpAddress) ProtoMessage()
- func (x *IpAddress) ProtoReflect() protoreflect.Message
- func (x *IpAddress) Reset()
- func (x *IpAddress) String() string
- type IpAddress_V4
- type IpAddress_V6
- type Message
- func (*Message) Descriptor() ([]byte, []int)deprecated
- func (x *Message) GetCloseControlChannelReq() *CloseControlChannelReq
- func (x *Message) GetCloseControlChannelRsp() *CloseControlChannelRsp
- func (x *Message) GetCloseTunnelReq() *CloseTunnelReq
- func (x *Message) GetCloseTunnelRsp() *CloseTunnelRsp
- func (x *Message) GetHeartbeat() *Heartbeat
- func (x *Message) GetOpenControlChannelReq() *OpenControlChannelReq
- func (x *Message) GetOpenControlChannelRsp() *OpenControlChannelRsp
- func (x *Message) GetOpenTunnelReq() *OpenTunnelReq
- func (x *Message) GetOpenTunnelRsp() *OpenTunnelRsp
- func (x *Message) GetPayload() isMessage_Payload
- func (x *Message) GetProxyConnReq() *ProxyConnReq
- func (x *Message) GetProxyConnRsp() *ProxyConnRsp
- func (x *Message) GetProxyReq() *ProxyReq
- func (x *Message) GetProxyRsp() *ProxyRsp
- func (x *Message) GetServerMessage() *ServerMessage
- func (x *Message) GetStreamReq() *StreamReq
- func (x *Message) GetStreamRsp() *StreamRsp
- func (*Message) ProtoMessage()
- func (x *Message) ProtoReflect() protoreflect.Message
- func (x *Message) Reset()
- func (x *Message) String() string
- type Message_CloseControlChannelReq
- type Message_CloseControlChannelRsp
- type Message_CloseTunnelReq
- type Message_CloseTunnelRsp
- type Message_Heartbeat
- type Message_OpenControlChannelReq
- type Message_OpenControlChannelRsp
- type Message_OpenTunnelReq
- type Message_OpenTunnelRsp
- type Message_ProxyConnReq
- type Message_ProxyConnRsp
- type Message_ProxyReq
- type Message_ProxyRsp
- type Message_ServerMessage
- type Message_StreamReq
- type Message_StreamRsp
- type OpenControlChannelReq
- func (*OpenControlChannelReq) Descriptor() ([]byte, []int)deprecated
- func (x *OpenControlChannelReq) GetClientDetails() *ClientDetails
- func (*OpenControlChannelReq) ProtoMessage()
- func (x *OpenControlChannelReq) ProtoReflect() protoreflect.Message
- func (x *OpenControlChannelReq) Reset()
- func (x *OpenControlChannelReq) String() string
- type OpenControlChannelRsp
- func (*OpenControlChannelRsp) Descriptor() ([]byte, []int)deprecated
- func (x *OpenControlChannelRsp) GetError() *Error
- func (x *OpenControlChannelRsp) GetOk() *OpenControlChannelRsp_Ok
- func (x *OpenControlChannelRsp) GetPayload() isOpenControlChannelRsp_Payload
- func (*OpenControlChannelRsp) ProtoMessage()
- func (x *OpenControlChannelRsp) ProtoReflect() protoreflect.Message
- func (x *OpenControlChannelRsp) Reset()
- func (x *OpenControlChannelRsp) String() string
- type OpenControlChannelRsp_Error
- type OpenControlChannelRsp_Ok
- func (*OpenControlChannelRsp_Ok) Descriptor() ([]byte, []int)deprecated
- func (x *OpenControlChannelRsp_Ok) GetClientId() string
- func (x *OpenControlChannelRsp_Ok) GetServerDetails() *ServerDetails
- func (*OpenControlChannelRsp_Ok) ProtoMessage()
- func (x *OpenControlChannelRsp_Ok) ProtoReflect() protoreflect.Message
- func (x *OpenControlChannelRsp_Ok) Reset()
- func (x *OpenControlChannelRsp_Ok) String() string
- type OpenControlChannelRsp_Ok_
- type OpenTunnelReq
- func (*OpenTunnelReq) Descriptor() ([]byte, []int)deprecated
- func (x *OpenTunnelReq) GetRequestId() string
- func (x *OpenTunnelReq) GetTunnelProperties() *TunnelProperties
- func (*OpenTunnelReq) ProtoMessage()
- func (x *OpenTunnelReq) ProtoReflect() protoreflect.Message
- func (x *OpenTunnelReq) Reset()
- func (x *OpenTunnelReq) String() string
- type OpenTunnelRsp
- func (*OpenTunnelRsp) Descriptor() ([]byte, []int)deprecated
- func (x *OpenTunnelRsp) GetError() *Error
- func (x *OpenTunnelRsp) GetPayload() isOpenTunnelRsp_Payload
- func (x *OpenTunnelRsp) GetRequestId() string
- func (x *OpenTunnelRsp) GetTunnelProperties() *TunnelProperties
- func (*OpenTunnelRsp) ProtoMessage()
- func (x *OpenTunnelRsp) ProtoReflect() protoreflect.Message
- func (x *OpenTunnelRsp) Reset()
- func (x *OpenTunnelRsp) String() string
- type OpenTunnelRsp_Error
- type OpenTunnelRsp_TunnelProperties
- type ProxyConnReq
- func (*ProxyConnReq) Descriptor() ([]byte, []int)deprecated
- func (x *ProxyConnReq) GetSecret() *wrapperspb.StringValue
- func (x *ProxyConnReq) GetSourceIp() *IpAddress
- func (x *ProxyConnReq) GetStreamId() string
- func (x *ProxyConnReq) GetTunnelId() string
- func (*ProxyConnReq) ProtoMessage()
- func (x *ProxyConnReq) ProtoReflect() protoreflect.Message
- func (x *ProxyConnReq) Reset()
- func (x *ProxyConnReq) String() string
- type ProxyConnRsp
- func (*ProxyConnRsp) Descriptor() ([]byte, []int)deprecated
- func (x *ProxyConnRsp) GetError() *Error
- func (x *ProxyConnRsp) GetStreamId() string
- func (*ProxyConnRsp) ProtoMessage()
- func (x *ProxyConnRsp) ProtoReflect() protoreflect.Message
- func (x *ProxyConnRsp) Reset()
- func (x *ProxyConnRsp) String() string
- type ProxyReq
- func (*ProxyReq) Descriptor() ([]byte, []int)deprecated
- func (x *ProxyReq) GetClientDetails() *ClientDetails
- func (x *ProxyReq) GetStreamId() string
- func (x *ProxyReq) GetZeroRtt() *wrapperspb.BoolValue
- func (*ProxyReq) ProtoMessage()
- func (x *ProxyReq) ProtoReflect() protoreflect.Message
- func (x *ProxyReq) Reset()
- func (x *ProxyReq) String() string
- type ProxyRsp
- type ServerDetails
- func (*ServerDetails) Descriptor() ([]byte, []int)deprecated
- func (x *ServerDetails) GetAgent() *wrapperspb.StringValue
- func (x *ServerDetails) GetChannel() *wrapperspb.StringValue
- func (x *ServerDetails) GetPlan() *wrapperspb.StringValue
- func (x *ServerDetails) GetProvider() *wrapperspb.StringValue
- func (x *ServerDetails) GetRegion() *wrapperspb.StringValue
- func (x *ServerDetails) GetUpdate() *wrapperspb.StringValue
- func (x *ServerDetails) GetVersion() *wrapperspb.StringValue
- func (*ServerDetails) ProtoMessage()
- func (x *ServerDetails) ProtoReflect() protoreflect.Message
- func (x *ServerDetails) Reset()
- func (x *ServerDetails) String() string
- type ServerMessage
- type StreamReq
- func (*StreamReq) Descriptor() ([]byte, []int)deprecated
- func (x *StreamReq) GetClientDetails() *ClientDetails
- func (x *StreamReq) GetTunnelIdName() string
- func (x *StreamReq) GetZeroRtt() *wrapperspb.BoolValue
- func (*StreamReq) ProtoMessage()
- func (x *StreamReq) ProtoReflect() protoreflect.Message
- func (x *StreamReq) Reset()
- func (x *StreamReq) String() string
- type StreamRsp
- func (*StreamRsp) Descriptor() ([]byte, []int)deprecated
- func (x *StreamRsp) GetError() *Error
- func (x *StreamRsp) GetPayload() isStreamRsp_Payload
- func (x *StreamRsp) GetStreamId() string
- func (*StreamRsp) ProtoMessage()
- func (x *StreamRsp) ProtoReflect() protoreflect.Message
- func (x *StreamRsp) Reset()
- func (x *StreamRsp) String() string
- type StreamRsp_Error
- type StreamRsp_StreamId
- type TunnelProperties
- func (*TunnelProperties) Descriptor() ([]byte, []int)deprecated
- func (x *TunnelProperties) GetChallengeMode() *wrapperspb.BoolValue
- func (x *TunnelProperties) GetCreationDate() *timestamppb.Timestamp
- func (x *TunnelProperties) GetGeoip() []string
- func (x *TunnelProperties) GetHost() *wrapperspb.StringValuedeprecated
- func (x *TunnelProperties) GetHostname() *wrapperspb.StringValue
- func (x *TunnelProperties) GetHttpUseTls() *wrapperspb.BoolValuedeprecated
- func (x *TunnelProperties) GetHttpVersion() *wrapperspb.StringValue
- func (x *TunnelProperties) GetId() *wrapperspb.StringValue
- func (x *TunnelProperties) GetLabels() map[string]string
- func (x *TunnelProperties) GetMtlsAuth() *wrapperspb.BoolValue
- func (x *TunnelProperties) GetMtlsCacertPem() *wrapperspb.StringValuedeprecated
- func (x *TunnelProperties) GetName() *wrapperspb.StringValue
- func (x *TunnelProperties) GetPort() *wrapperspb.UInt32Value
- func (x *TunnelProperties) GetProtocol() *wrapperspb.StringValue
- func (x *TunnelProperties) GetPublish() *wrapperspb.BoolValue
- func (x *TunnelProperties) GetRstreamAuth() *wrapperspb.BoolValue
- func (x *TunnelProperties) GetTlsAlpns() []string
- func (x *TunnelProperties) GetTlsCiphers() []string
- func (x *TunnelProperties) GetTlsMinVersion() *wrapperspb.StringValue
- func (x *TunnelProperties) GetTlsMode() *wrapperspb.StringValue
- func (x *TunnelProperties) GetTokenAuth() *wrapperspb.BoolValue
- func (x *TunnelProperties) GetTrustedIps() []string
- func (x *TunnelProperties) GetType() *wrapperspb.StringValue
- func (x *TunnelProperties) GetUpstreamTls() *wrapperspb.BoolValue
- func (*TunnelProperties) ProtoMessage()
- func (x *TunnelProperties) ProtoReflect() protoreflect.Message
- func (x *TunnelProperties) Reset()
- func (x *TunnelProperties) String() string
Constants ¶
This section is empty.
Variables ¶
var ( ErrorCode_name = map[int32]string{ 0: "ERROR_CODE_UNSPECIFIED", 1000: "ERROR_CODE_UNAUTHORIZED", 2000: "ERROR_CODE_INVALID_REQUEST", 2010: "ERROR_CODE_PROTOCOL_VERSION_MISSING", 2020: "ERROR_CODE_PROTOCOL_VERSION_INVALID", 2030: "ERROR_CODE_PROTOCOL_VERSION_INCOMPATIBLE", 3000: "ERROR_CODE_TUNNEL_NOT_FOUND", 4000: "ERROR_CODE_INVALID_STREAM", 5000: "ERROR_CODE_FEATURE_NOT_AVAILABLE", 6000: "ERROR_CODE_SERVICE_UNAVAILABLE", 9000: "ERROR_CODE_INTERNAL", } ErrorCode_value = map[string]int32{ "ERROR_CODE_UNSPECIFIED": 0, "ERROR_CODE_UNAUTHORIZED": 1000, "ERROR_CODE_INVALID_REQUEST": 2000, "ERROR_CODE_PROTOCOL_VERSION_MISSING": 2010, "ERROR_CODE_PROTOCOL_VERSION_INVALID": 2020, "ERROR_CODE_PROTOCOL_VERSION_INCOMPATIBLE": 2030, "ERROR_CODE_TUNNEL_NOT_FOUND": 3000, "ERROR_CODE_INVALID_STREAM": 4000, "ERROR_CODE_FEATURE_NOT_AVAILABLE": 5000, "ERROR_CODE_SERVICE_UNAVAILABLE": 6000, "ERROR_CODE_INTERNAL": 9000, } )
Enum value maps for ErrorCode.
var (
// optional string access = 51234;
E_Access = &file_pb_rstream_proto_extTypes[1]
)
Extension fields to descriptorpb.FieldOptions.
var (
// optional string protocol_version = 51000;
E_ProtocolVersion = &file_pb_rstream_proto_extTypes[0]
)
Extension fields to descriptorpb.FileOptions.
var File_pb_rstream_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ClientDetails ¶
type ClientDetails struct {
Agent *wrapperspb.StringValue `protobuf:"bytes,1,opt,name=agent,proto3" json:"agent,omitempty"`
Channel *wrapperspb.StringValue `protobuf:"bytes,2,opt,name=channel,proto3" json:"channel,omitempty"`
Version *wrapperspb.StringValue `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
Os *wrapperspb.StringValue `protobuf:"bytes,4,opt,name=os,proto3" json:"os,omitempty"`
Arch *wrapperspb.StringValue `protobuf:"bytes,5,opt,name=arch,proto3" json:"arch,omitempty"`
Token *wrapperspb.StringValue `protobuf:"bytes,6,opt,name=token,proto3" json:"token,omitempty"`
ProtocolVersion *wrapperspb.StringValue `protobuf:"bytes,7,opt,name=protocol_version,json=protocolVersion,proto3" json:"protocol_version,omitempty"`
// contains filtered or unexported fields
}
func (*ClientDetails) Descriptor
deprecated
func (*ClientDetails) Descriptor() ([]byte, []int)
Deprecated: Use ClientDetails.ProtoReflect.Descriptor instead.
func (*ClientDetails) GetAgent ¶
func (x *ClientDetails) GetAgent() *wrapperspb.StringValue
func (*ClientDetails) GetArch ¶
func (x *ClientDetails) GetArch() *wrapperspb.StringValue
func (*ClientDetails) GetChannel ¶ added in v1.3.0
func (x *ClientDetails) GetChannel() *wrapperspb.StringValue
func (*ClientDetails) GetOs ¶
func (x *ClientDetails) GetOs() *wrapperspb.StringValue
func (*ClientDetails) GetProtocolVersion ¶
func (x *ClientDetails) GetProtocolVersion() *wrapperspb.StringValue
func (*ClientDetails) GetToken ¶
func (x *ClientDetails) GetToken() *wrapperspb.StringValue
func (*ClientDetails) GetVersion ¶
func (x *ClientDetails) GetVersion() *wrapperspb.StringValue
func (*ClientDetails) ProtoMessage ¶
func (*ClientDetails) ProtoMessage()
func (*ClientDetails) ProtoReflect ¶
func (x *ClientDetails) ProtoReflect() protoreflect.Message
func (*ClientDetails) Reset ¶
func (x *ClientDetails) Reset()
func (*ClientDetails) String ¶
func (x *ClientDetails) String() string
type CloseControlChannelReq ¶
type CloseControlChannelReq struct {
// contains filtered or unexported fields
}
func (*CloseControlChannelReq) Descriptor
deprecated
func (*CloseControlChannelReq) Descriptor() ([]byte, []int)
Deprecated: Use CloseControlChannelReq.ProtoReflect.Descriptor instead.
func (*CloseControlChannelReq) ProtoMessage ¶
func (*CloseControlChannelReq) ProtoMessage()
func (*CloseControlChannelReq) ProtoReflect ¶
func (x *CloseControlChannelReq) ProtoReflect() protoreflect.Message
func (*CloseControlChannelReq) Reset ¶
func (x *CloseControlChannelReq) Reset()
func (*CloseControlChannelReq) String ¶
func (x *CloseControlChannelReq) String() string
type CloseControlChannelRsp ¶
type CloseControlChannelRsp struct {
// contains filtered or unexported fields
}
func (*CloseControlChannelRsp) Descriptor
deprecated
func (*CloseControlChannelRsp) Descriptor() ([]byte, []int)
Deprecated: Use CloseControlChannelRsp.ProtoReflect.Descriptor instead.
func (*CloseControlChannelRsp) ProtoMessage ¶
func (*CloseControlChannelRsp) ProtoMessage()
func (*CloseControlChannelRsp) ProtoReflect ¶
func (x *CloseControlChannelRsp) ProtoReflect() protoreflect.Message
func (*CloseControlChannelRsp) Reset ¶
func (x *CloseControlChannelRsp) Reset()
func (*CloseControlChannelRsp) String ¶
func (x *CloseControlChannelRsp) String() string
type CloseTunnelReq ¶
type CloseTunnelReq struct {
TunnelId string `protobuf:"bytes,1,opt,name=tunnel_id,json=tunnelId,proto3" json:"tunnel_id,omitempty"`
// contains filtered or unexported fields
}
func (*CloseTunnelReq) Descriptor
deprecated
func (*CloseTunnelReq) Descriptor() ([]byte, []int)
Deprecated: Use CloseTunnelReq.ProtoReflect.Descriptor instead.
func (*CloseTunnelReq) GetTunnelId ¶
func (x *CloseTunnelReq) GetTunnelId() string
func (*CloseTunnelReq) ProtoMessage ¶
func (*CloseTunnelReq) ProtoMessage()
func (*CloseTunnelReq) ProtoReflect ¶
func (x *CloseTunnelReq) ProtoReflect() protoreflect.Message
func (*CloseTunnelReq) Reset ¶
func (x *CloseTunnelReq) Reset()
func (*CloseTunnelReq) String ¶
func (x *CloseTunnelReq) String() string
type CloseTunnelRsp ¶
type CloseTunnelRsp struct {
TunnelId string `protobuf:"bytes,1,opt,name=tunnel_id,json=tunnelId,proto3" json:"tunnel_id,omitempty"`
// contains filtered or unexported fields
}
func (*CloseTunnelRsp) Descriptor
deprecated
func (*CloseTunnelRsp) Descriptor() ([]byte, []int)
Deprecated: Use CloseTunnelRsp.ProtoReflect.Descriptor instead.
func (*CloseTunnelRsp) GetTunnelId ¶
func (x *CloseTunnelRsp) GetTunnelId() string
func (*CloseTunnelRsp) ProtoMessage ¶
func (*CloseTunnelRsp) ProtoMessage()
func (*CloseTunnelRsp) ProtoReflect ¶
func (x *CloseTunnelRsp) ProtoReflect() protoreflect.Message
func (*CloseTunnelRsp) Reset ¶
func (x *CloseTunnelRsp) Reset()
func (*CloseTunnelRsp) String ¶
func (x *CloseTunnelRsp) String() string
type Error ¶
type Error struct {
Code ErrorCode `protobuf:"varint,1,opt,name=code,proto3,enum=rstream.io_rstrm.protobuf.ErrorCode" json:"code,omitempty"`
Message *wrapperspb.StringValue `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*Error) Descriptor
deprecated
func (*Error) GetMessage ¶
func (x *Error) GetMessage() *wrapperspb.StringValue
func (*Error) ProtoMessage ¶
func (*Error) ProtoMessage()
func (*Error) ProtoReflect ¶
func (x *Error) ProtoReflect() protoreflect.Message
type ErrorCode ¶ added in v1.4.0
type ErrorCode int32
Error codes grouped by class
1000-1999: Authentication / authorization 2000-2999: Request validation / protocol 3000-3999: Not found 4000-4999: Invalid state / stream 5000-5999: Feature / plan / config not available 6000-6999: Service dependency unavailable 9000-9999: Internal errors
const ( ErrorCode_ERROR_CODE_UNSPECIFIED ErrorCode = 0 // 1000-1999: Authentication / authorization ErrorCode_ERROR_CODE_UNAUTHORIZED ErrorCode = 1000 // 2000-2999: Request validation / protocol ErrorCode_ERROR_CODE_INVALID_REQUEST ErrorCode = 2000 ErrorCode_ERROR_CODE_PROTOCOL_VERSION_MISSING ErrorCode = 2010 ErrorCode_ERROR_CODE_PROTOCOL_VERSION_INVALID ErrorCode = 2020 ErrorCode_ERROR_CODE_PROTOCOL_VERSION_INCOMPATIBLE ErrorCode = 2030 // 3000-3999: Not found ErrorCode_ERROR_CODE_TUNNEL_NOT_FOUND ErrorCode = 3000 // 4000-4999: Invalid state / stream ErrorCode_ERROR_CODE_INVALID_STREAM ErrorCode = 4000 // 5000-5999: Feature / plan / config not available ErrorCode_ERROR_CODE_FEATURE_NOT_AVAILABLE ErrorCode = 5000 // 6000-6999: Service dependency unavailable ErrorCode_ERROR_CODE_SERVICE_UNAVAILABLE ErrorCode = 6000 // 9000-9999: Internal errors ErrorCode_ERROR_CODE_INTERNAL ErrorCode = 9000 )
func (ErrorCode) Descriptor ¶ added in v1.4.0
func (ErrorCode) Descriptor() protoreflect.EnumDescriptor
func (ErrorCode) EnumDescriptor
deprecated
added in
v1.4.0
func (ErrorCode) Number ¶ added in v1.4.0
func (x ErrorCode) Number() protoreflect.EnumNumber
func (ErrorCode) Type ¶ added in v1.4.0
func (ErrorCode) Type() protoreflect.EnumType
type Heartbeat ¶
type Heartbeat struct {
// contains filtered or unexported fields
}
func (*Heartbeat) Descriptor
deprecated
func (*Heartbeat) ProtoMessage ¶
func (*Heartbeat) ProtoMessage()
func (*Heartbeat) ProtoReflect ¶
func (x *Heartbeat) ProtoReflect() protoreflect.Message
type IpAddress ¶
type IpAddress struct {
// Types that are valid to be assigned to Addr:
//
// *IpAddress_V4
// *IpAddress_V6
Addr isIpAddress_Addr `protobuf_oneof:"addr"`
// contains filtered or unexported fields
}
func (*IpAddress) Descriptor
deprecated
func (*IpAddress) ProtoMessage ¶
func (*IpAddress) ProtoMessage()
func (*IpAddress) ProtoReflect ¶
func (x *IpAddress) ProtoReflect() protoreflect.Message
type IpAddress_V4 ¶
type IpAddress_V4 struct {
V4 uint32 `protobuf:"fixed32,1,opt,name=v4,proto3,oneof"`
}
type IpAddress_V6 ¶
type IpAddress_V6 struct {
V6 []byte `protobuf:"bytes,2,opt,name=v6,proto3,oneof"`
}
type Message ¶
type Message struct {
// Types that are valid to be assigned to Payload:
//
// *Message_OpenControlChannelReq
// *Message_OpenControlChannelRsp
// *Message_CloseControlChannelReq
// *Message_CloseControlChannelRsp
// *Message_OpenTunnelReq
// *Message_OpenTunnelRsp
// *Message_CloseTunnelReq
// *Message_CloseTunnelRsp
// *Message_ProxyConnReq
// *Message_ProxyConnRsp
// *Message_ProxyReq
// *Message_ProxyRsp
// *Message_StreamReq
// *Message_StreamRsp
// *Message_Heartbeat
// *Message_ServerMessage
Payload isMessage_Payload `protobuf_oneof:"payload"`
// contains filtered or unexported fields
}
func (*Message) Descriptor
deprecated
func (*Message) GetCloseControlChannelReq ¶
func (x *Message) GetCloseControlChannelReq() *CloseControlChannelReq
func (*Message) GetCloseControlChannelRsp ¶
func (x *Message) GetCloseControlChannelRsp() *CloseControlChannelRsp
func (*Message) GetCloseTunnelReq ¶
func (x *Message) GetCloseTunnelReq() *CloseTunnelReq
func (*Message) GetCloseTunnelRsp ¶
func (x *Message) GetCloseTunnelRsp() *CloseTunnelRsp
func (*Message) GetHeartbeat ¶
func (*Message) GetOpenControlChannelReq ¶
func (x *Message) GetOpenControlChannelReq() *OpenControlChannelReq
func (*Message) GetOpenControlChannelRsp ¶
func (x *Message) GetOpenControlChannelRsp() *OpenControlChannelRsp
func (*Message) GetOpenTunnelReq ¶
func (x *Message) GetOpenTunnelReq() *OpenTunnelReq
func (*Message) GetOpenTunnelRsp ¶
func (x *Message) GetOpenTunnelRsp() *OpenTunnelRsp
func (*Message) GetPayload ¶
func (x *Message) GetPayload() isMessage_Payload
func (*Message) GetProxyConnReq ¶
func (x *Message) GetProxyConnReq() *ProxyConnReq
func (*Message) GetProxyConnRsp ¶
func (x *Message) GetProxyConnRsp() *ProxyConnRsp
func (*Message) GetProxyReq ¶
func (*Message) GetProxyRsp ¶
func (*Message) GetServerMessage ¶
func (x *Message) GetServerMessage() *ServerMessage
func (*Message) GetStreamReq ¶
func (*Message) GetStreamRsp ¶
func (*Message) ProtoMessage ¶
func (*Message) ProtoMessage()
func (*Message) ProtoReflect ¶
func (x *Message) ProtoReflect() protoreflect.Message
type Message_CloseControlChannelReq ¶
type Message_CloseControlChannelReq struct {
CloseControlChannelReq *CloseControlChannelReq `protobuf:"bytes,3,opt,name=close_control_channel_req,json=closeControlChannelReq,proto3,oneof"`
}
type Message_CloseControlChannelRsp ¶
type Message_CloseControlChannelRsp struct {
CloseControlChannelRsp *CloseControlChannelRsp `protobuf:"bytes,4,opt,name=close_control_channel_rsp,json=closeControlChannelRsp,proto3,oneof"`
}
type Message_CloseTunnelReq ¶
type Message_CloseTunnelReq struct {
CloseTunnelReq *CloseTunnelReq `protobuf:"bytes,7,opt,name=close_tunnel_req,json=closeTunnelReq,proto3,oneof"`
}
type Message_CloseTunnelRsp ¶
type Message_CloseTunnelRsp struct {
CloseTunnelRsp *CloseTunnelRsp `protobuf:"bytes,8,opt,name=close_tunnel_rsp,json=closeTunnelRsp,proto3,oneof"`
}
type Message_Heartbeat ¶
type Message_Heartbeat struct {
Heartbeat *Heartbeat `protobuf:"bytes,15,opt,name=heartbeat,proto3,oneof"`
}
type Message_OpenControlChannelReq ¶
type Message_OpenControlChannelReq struct {
OpenControlChannelReq *OpenControlChannelReq `protobuf:"bytes,1,opt,name=open_control_channel_req,json=openControlChannelReq,proto3,oneof"`
}
type Message_OpenControlChannelRsp ¶
type Message_OpenControlChannelRsp struct {
OpenControlChannelRsp *OpenControlChannelRsp `protobuf:"bytes,2,opt,name=open_control_channel_rsp,json=openControlChannelRsp,proto3,oneof"`
}
type Message_OpenTunnelReq ¶
type Message_OpenTunnelReq struct {
OpenTunnelReq *OpenTunnelReq `protobuf:"bytes,5,opt,name=open_tunnel_req,json=openTunnelReq,proto3,oneof"`
}
type Message_OpenTunnelRsp ¶
type Message_OpenTunnelRsp struct {
OpenTunnelRsp *OpenTunnelRsp `protobuf:"bytes,6,opt,name=open_tunnel_rsp,json=openTunnelRsp,proto3,oneof"`
}
type Message_ProxyConnReq ¶
type Message_ProxyConnReq struct {
ProxyConnReq *ProxyConnReq `protobuf:"bytes,9,opt,name=proxy_conn_req,json=proxyConnReq,proto3,oneof"`
}
type Message_ProxyConnRsp ¶
type Message_ProxyConnRsp struct {
ProxyConnRsp *ProxyConnRsp `protobuf:"bytes,10,opt,name=proxy_conn_rsp,json=proxyConnRsp,proto3,oneof"`
}
type Message_ProxyReq ¶
type Message_ProxyReq struct {
ProxyReq *ProxyReq `protobuf:"bytes,11,opt,name=proxy_req,json=proxyReq,proto3,oneof"`
}
type Message_ProxyRsp ¶
type Message_ProxyRsp struct {
ProxyRsp *ProxyRsp `protobuf:"bytes,12,opt,name=proxy_rsp,json=proxyRsp,proto3,oneof"`
}
type Message_ServerMessage ¶
type Message_ServerMessage struct {
ServerMessage *ServerMessage `protobuf:"bytes,16,opt,name=server_message,json=serverMessage,proto3,oneof"`
}
type Message_StreamReq ¶
type Message_StreamReq struct {
StreamReq *StreamReq `protobuf:"bytes,13,opt,name=stream_req,json=streamReq,proto3,oneof"`
}
type Message_StreamRsp ¶
type Message_StreamRsp struct {
StreamRsp *StreamRsp `protobuf:"bytes,14,opt,name=stream_rsp,json=streamRsp,proto3,oneof"`
}
type OpenControlChannelReq ¶
type OpenControlChannelReq struct {
ClientDetails *ClientDetails `protobuf:"bytes,1,opt,name=client_details,json=clientDetails,proto3" json:"client_details,omitempty"`
// contains filtered or unexported fields
}
func (*OpenControlChannelReq) Descriptor
deprecated
func (*OpenControlChannelReq) Descriptor() ([]byte, []int)
Deprecated: Use OpenControlChannelReq.ProtoReflect.Descriptor instead.
func (*OpenControlChannelReq) GetClientDetails ¶
func (x *OpenControlChannelReq) GetClientDetails() *ClientDetails
func (*OpenControlChannelReq) ProtoMessage ¶
func (*OpenControlChannelReq) ProtoMessage()
func (*OpenControlChannelReq) ProtoReflect ¶
func (x *OpenControlChannelReq) ProtoReflect() protoreflect.Message
func (*OpenControlChannelReq) Reset ¶
func (x *OpenControlChannelReq) Reset()
func (*OpenControlChannelReq) String ¶
func (x *OpenControlChannelReq) String() string
type OpenControlChannelRsp ¶
type OpenControlChannelRsp struct {
// Types that are valid to be assigned to Payload:
//
// *OpenControlChannelRsp_Ok_
// *OpenControlChannelRsp_Error
Payload isOpenControlChannelRsp_Payload `protobuf_oneof:"payload"`
// contains filtered or unexported fields
}
func (*OpenControlChannelRsp) Descriptor
deprecated
func (*OpenControlChannelRsp) Descriptor() ([]byte, []int)
Deprecated: Use OpenControlChannelRsp.ProtoReflect.Descriptor instead.
func (*OpenControlChannelRsp) GetError ¶
func (x *OpenControlChannelRsp) GetError() *Error
func (*OpenControlChannelRsp) GetOk ¶ added in v1.3.0
func (x *OpenControlChannelRsp) GetOk() *OpenControlChannelRsp_Ok
func (*OpenControlChannelRsp) GetPayload ¶
func (x *OpenControlChannelRsp) GetPayload() isOpenControlChannelRsp_Payload
func (*OpenControlChannelRsp) ProtoMessage ¶
func (*OpenControlChannelRsp) ProtoMessage()
func (*OpenControlChannelRsp) ProtoReflect ¶
func (x *OpenControlChannelRsp) ProtoReflect() protoreflect.Message
func (*OpenControlChannelRsp) Reset ¶
func (x *OpenControlChannelRsp) Reset()
func (*OpenControlChannelRsp) String ¶
func (x *OpenControlChannelRsp) String() string
type OpenControlChannelRsp_Error ¶
type OpenControlChannelRsp_Error struct {
Error *Error `protobuf:"bytes,2,opt,name=error,proto3,oneof"`
}
type OpenControlChannelRsp_Ok ¶ added in v1.3.0
type OpenControlChannelRsp_Ok struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
ServerDetails *ServerDetails `protobuf:"bytes,2,opt,name=server_details,json=serverDetails,proto3" json:"server_details,omitempty"`
// contains filtered or unexported fields
}
func (*OpenControlChannelRsp_Ok) Descriptor
deprecated
added in
v1.3.0
func (*OpenControlChannelRsp_Ok) Descriptor() ([]byte, []int)
Deprecated: Use OpenControlChannelRsp_Ok.ProtoReflect.Descriptor instead.
func (*OpenControlChannelRsp_Ok) GetClientId ¶ added in v1.3.0
func (x *OpenControlChannelRsp_Ok) GetClientId() string
func (*OpenControlChannelRsp_Ok) GetServerDetails ¶ added in v1.3.0
func (x *OpenControlChannelRsp_Ok) GetServerDetails() *ServerDetails
func (*OpenControlChannelRsp_Ok) ProtoMessage ¶ added in v1.3.0
func (*OpenControlChannelRsp_Ok) ProtoMessage()
func (*OpenControlChannelRsp_Ok) ProtoReflect ¶ added in v1.3.0
func (x *OpenControlChannelRsp_Ok) ProtoReflect() protoreflect.Message
func (*OpenControlChannelRsp_Ok) Reset ¶ added in v1.3.0
func (x *OpenControlChannelRsp_Ok) Reset()
func (*OpenControlChannelRsp_Ok) String ¶ added in v1.3.0
func (x *OpenControlChannelRsp_Ok) String() string
type OpenControlChannelRsp_Ok_ ¶ added in v1.3.0
type OpenControlChannelRsp_Ok_ struct {
Ok *OpenControlChannelRsp_Ok `protobuf:"bytes,1,opt,name=ok,proto3,oneof"`
}
type OpenTunnelReq ¶
type OpenTunnelReq struct {
RequestId string `protobuf:"bytes,1,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
TunnelProperties *TunnelProperties `protobuf:"bytes,2,opt,name=tunnel_properties,json=tunnelProperties,proto3" json:"tunnel_properties,omitempty"`
// contains filtered or unexported fields
}
func (*OpenTunnelReq) Descriptor
deprecated
func (*OpenTunnelReq) Descriptor() ([]byte, []int)
Deprecated: Use OpenTunnelReq.ProtoReflect.Descriptor instead.
func (*OpenTunnelReq) GetRequestId ¶
func (x *OpenTunnelReq) GetRequestId() string
func (*OpenTunnelReq) GetTunnelProperties ¶
func (x *OpenTunnelReq) GetTunnelProperties() *TunnelProperties
func (*OpenTunnelReq) ProtoMessage ¶
func (*OpenTunnelReq) ProtoMessage()
func (*OpenTunnelReq) ProtoReflect ¶
func (x *OpenTunnelReq) ProtoReflect() protoreflect.Message
func (*OpenTunnelReq) Reset ¶
func (x *OpenTunnelReq) Reset()
func (*OpenTunnelReq) String ¶
func (x *OpenTunnelReq) String() string
type OpenTunnelRsp ¶
type OpenTunnelRsp struct {
RequestId string `protobuf:"bytes,1,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// Types that are valid to be assigned to Payload:
//
// *OpenTunnelRsp_TunnelProperties
// *OpenTunnelRsp_Error
Payload isOpenTunnelRsp_Payload `protobuf_oneof:"payload"`
// contains filtered or unexported fields
}
func (*OpenTunnelRsp) Descriptor
deprecated
func (*OpenTunnelRsp) Descriptor() ([]byte, []int)
Deprecated: Use OpenTunnelRsp.ProtoReflect.Descriptor instead.
func (*OpenTunnelRsp) GetError ¶
func (x *OpenTunnelRsp) GetError() *Error
func (*OpenTunnelRsp) GetPayload ¶
func (x *OpenTunnelRsp) GetPayload() isOpenTunnelRsp_Payload
func (*OpenTunnelRsp) GetRequestId ¶
func (x *OpenTunnelRsp) GetRequestId() string
func (*OpenTunnelRsp) GetTunnelProperties ¶
func (x *OpenTunnelRsp) GetTunnelProperties() *TunnelProperties
func (*OpenTunnelRsp) ProtoMessage ¶
func (*OpenTunnelRsp) ProtoMessage()
func (*OpenTunnelRsp) ProtoReflect ¶
func (x *OpenTunnelRsp) ProtoReflect() protoreflect.Message
func (*OpenTunnelRsp) Reset ¶
func (x *OpenTunnelRsp) Reset()
func (*OpenTunnelRsp) String ¶
func (x *OpenTunnelRsp) String() string
type OpenTunnelRsp_Error ¶
type OpenTunnelRsp_Error struct {
Error *Error `protobuf:"bytes,3,opt,name=error,proto3,oneof"`
}
type OpenTunnelRsp_TunnelProperties ¶
type OpenTunnelRsp_TunnelProperties struct {
TunnelProperties *TunnelProperties `protobuf:"bytes,2,opt,name=tunnel_properties,json=tunnelProperties,proto3,oneof"`
}
type ProxyConnReq ¶
type ProxyConnReq struct {
TunnelId string `protobuf:"bytes,1,opt,name=tunnel_id,json=tunnelId,proto3" json:"tunnel_id,omitempty"`
StreamId string `protobuf:"bytes,2,opt,name=stream_id,json=streamId,proto3" json:"stream_id,omitempty"`
Secret *wrapperspb.StringValue `protobuf:"bytes,3,opt,name=secret,proto3" json:"secret,omitempty"`
SourceIp *IpAddress `protobuf:"bytes,4,opt,name=source_ip,json=sourceIp,proto3" json:"source_ip,omitempty"`
// contains filtered or unexported fields
}
func (*ProxyConnReq) Descriptor
deprecated
func (*ProxyConnReq) Descriptor() ([]byte, []int)
Deprecated: Use ProxyConnReq.ProtoReflect.Descriptor instead.
func (*ProxyConnReq) GetSecret ¶
func (x *ProxyConnReq) GetSecret() *wrapperspb.StringValue
func (*ProxyConnReq) GetSourceIp ¶
func (x *ProxyConnReq) GetSourceIp() *IpAddress
func (*ProxyConnReq) GetStreamId ¶
func (x *ProxyConnReq) GetStreamId() string
func (*ProxyConnReq) GetTunnelId ¶
func (x *ProxyConnReq) GetTunnelId() string
func (*ProxyConnReq) ProtoMessage ¶
func (*ProxyConnReq) ProtoMessage()
func (*ProxyConnReq) ProtoReflect ¶
func (x *ProxyConnReq) ProtoReflect() protoreflect.Message
func (*ProxyConnReq) Reset ¶
func (x *ProxyConnReq) Reset()
func (*ProxyConnReq) String ¶
func (x *ProxyConnReq) String() string
type ProxyConnRsp ¶
type ProxyConnRsp struct {
StreamId string `protobuf:"bytes,1,opt,name=stream_id,json=streamId,proto3" json:"stream_id,omitempty"`
Error *Error `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*ProxyConnRsp) Descriptor
deprecated
func (*ProxyConnRsp) Descriptor() ([]byte, []int)
Deprecated: Use ProxyConnRsp.ProtoReflect.Descriptor instead.
func (*ProxyConnRsp) GetError ¶
func (x *ProxyConnRsp) GetError() *Error
func (*ProxyConnRsp) GetStreamId ¶
func (x *ProxyConnRsp) GetStreamId() string
func (*ProxyConnRsp) ProtoMessage ¶
func (*ProxyConnRsp) ProtoMessage()
func (*ProxyConnRsp) ProtoReflect ¶
func (x *ProxyConnRsp) ProtoReflect() protoreflect.Message
func (*ProxyConnRsp) Reset ¶
func (x *ProxyConnRsp) Reset()
func (*ProxyConnRsp) String ¶
func (x *ProxyConnRsp) String() string
type ProxyReq ¶
type ProxyReq struct {
ClientDetails *ClientDetails `protobuf:"bytes,1,opt,name=client_details,json=clientDetails,proto3" json:"client_details,omitempty"`
StreamId string `protobuf:"bytes,2,opt,name=stream_id,json=streamId,proto3" json:"stream_id,omitempty"`
ZeroRtt *wrapperspb.BoolValue `protobuf:"bytes,3,opt,name=zero_rtt,json=zeroRtt,proto3" json:"zero_rtt,omitempty"`
// contains filtered or unexported fields
}
func (*ProxyReq) Descriptor
deprecated
func (*ProxyReq) GetClientDetails ¶
func (x *ProxyReq) GetClientDetails() *ClientDetails
func (*ProxyReq) GetStreamId ¶
func (*ProxyReq) GetZeroRtt ¶
func (x *ProxyReq) GetZeroRtt() *wrapperspb.BoolValue
func (*ProxyReq) ProtoMessage ¶
func (*ProxyReq) ProtoMessage()
func (*ProxyReq) ProtoReflect ¶
func (x *ProxyReq) ProtoReflect() protoreflect.Message
type ProxyRsp ¶
type ProxyRsp struct {
Error *Error `protobuf:"bytes,1,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*ProxyRsp) Descriptor
deprecated
func (*ProxyRsp) ProtoMessage ¶
func (*ProxyRsp) ProtoMessage()
func (*ProxyRsp) ProtoReflect ¶
func (x *ProxyRsp) ProtoReflect() protoreflect.Message
type ServerDetails ¶ added in v1.3.0
type ServerDetails struct {
Agent *wrapperspb.StringValue `protobuf:"bytes,1,opt,name=agent,proto3" json:"agent,omitempty"`
Channel *wrapperspb.StringValue `protobuf:"bytes,2,opt,name=channel,proto3" json:"channel,omitempty"`
Version *wrapperspb.StringValue `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
Plan *wrapperspb.StringValue `protobuf:"bytes,4,opt,name=plan,proto3" json:"plan,omitempty"`
Provider *wrapperspb.StringValue `protobuf:"bytes,5,opt,name=provider,proto3" json:"provider,omitempty"`
Region *wrapperspb.StringValue `protobuf:"bytes,6,opt,name=region,proto3" json:"region,omitempty"`
Update *wrapperspb.StringValue `protobuf:"bytes,7,opt,name=update,proto3" json:"update,omitempty"`
// contains filtered or unexported fields
}
func (*ServerDetails) Descriptor
deprecated
added in
v1.3.0
func (*ServerDetails) Descriptor() ([]byte, []int)
Deprecated: Use ServerDetails.ProtoReflect.Descriptor instead.
func (*ServerDetails) GetAgent ¶ added in v1.3.0
func (x *ServerDetails) GetAgent() *wrapperspb.StringValue
func (*ServerDetails) GetChannel ¶ added in v1.3.0
func (x *ServerDetails) GetChannel() *wrapperspb.StringValue
func (*ServerDetails) GetPlan ¶ added in v1.3.0
func (x *ServerDetails) GetPlan() *wrapperspb.StringValue
func (*ServerDetails) GetProvider ¶ added in v1.3.0
func (x *ServerDetails) GetProvider() *wrapperspb.StringValue
func (*ServerDetails) GetRegion ¶ added in v1.3.0
func (x *ServerDetails) GetRegion() *wrapperspb.StringValue
func (*ServerDetails) GetUpdate ¶ added in v1.3.0
func (x *ServerDetails) GetUpdate() *wrapperspb.StringValue
func (*ServerDetails) GetVersion ¶ added in v1.3.0
func (x *ServerDetails) GetVersion() *wrapperspb.StringValue
func (*ServerDetails) ProtoMessage ¶ added in v1.3.0
func (*ServerDetails) ProtoMessage()
func (*ServerDetails) ProtoReflect ¶ added in v1.3.0
func (x *ServerDetails) ProtoReflect() protoreflect.Message
func (*ServerDetails) Reset ¶ added in v1.3.0
func (x *ServerDetails) Reset()
func (*ServerDetails) String ¶ added in v1.3.0
func (x *ServerDetails) String() string
type ServerMessage ¶
type ServerMessage struct {
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
Allows the server to send unsolicited messages to the client
func (*ServerMessage) Descriptor
deprecated
func (*ServerMessage) Descriptor() ([]byte, []int)
Deprecated: Use ServerMessage.ProtoReflect.Descriptor instead.
func (*ServerMessage) GetMessage ¶
func (x *ServerMessage) GetMessage() string
func (*ServerMessage) ProtoMessage ¶
func (*ServerMessage) ProtoMessage()
func (*ServerMessage) ProtoReflect ¶
func (x *ServerMessage) ProtoReflect() protoreflect.Message
func (*ServerMessage) Reset ¶
func (x *ServerMessage) Reset()
func (*ServerMessage) String ¶
func (x *ServerMessage) String() string
type StreamReq ¶
type StreamReq struct {
ClientDetails *ClientDetails `protobuf:"bytes,1,opt,name=client_details,json=clientDetails,proto3" json:"client_details,omitempty"`
TunnelIdName string `protobuf:"bytes,2,opt,name=tunnel_id_name,json=tunnelIdName,proto3" json:"tunnel_id_name,omitempty"`
ZeroRtt *wrapperspb.BoolValue `protobuf:"bytes,3,opt,name=zero_rtt,json=zeroRtt,proto3" json:"zero_rtt,omitempty"`
// contains filtered or unexported fields
}
func (*StreamReq) Descriptor
deprecated
func (*StreamReq) GetClientDetails ¶
func (x *StreamReq) GetClientDetails() *ClientDetails
func (*StreamReq) GetTunnelIdName ¶
func (*StreamReq) GetZeroRtt ¶
func (x *StreamReq) GetZeroRtt() *wrapperspb.BoolValue
func (*StreamReq) ProtoMessage ¶
func (*StreamReq) ProtoMessage()
func (*StreamReq) ProtoReflect ¶
func (x *StreamReq) ProtoReflect() protoreflect.Message
type StreamRsp ¶
type StreamRsp struct {
// Types that are valid to be assigned to Payload:
//
// *StreamRsp_StreamId
// *StreamRsp_Error
Payload isStreamRsp_Payload `protobuf_oneof:"payload"`
// contains filtered or unexported fields
}
func (*StreamRsp) Descriptor
deprecated
func (*StreamRsp) GetPayload ¶
func (x *StreamRsp) GetPayload() isStreamRsp_Payload
func (*StreamRsp) GetStreamId ¶
func (*StreamRsp) ProtoMessage ¶
func (*StreamRsp) ProtoMessage()
func (*StreamRsp) ProtoReflect ¶
func (x *StreamRsp) ProtoReflect() protoreflect.Message
type StreamRsp_Error ¶
type StreamRsp_Error struct {
Error *Error `protobuf:"bytes,2,opt,name=error,proto3,oneof"`
}
type StreamRsp_StreamId ¶
type StreamRsp_StreamId struct {
StreamId string `protobuf:"bytes,1,opt,name=stream_id,json=streamId,proto3,oneof"`
}
type TunnelProperties ¶
type TunnelProperties struct {
Id *wrapperspb.StringValue `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
CreationDate *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=creation_date,json=creationDate,proto3" json:"creation_date,omitempty"`
Name *wrapperspb.StringValue `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
Type *wrapperspb.StringValue `protobuf:"bytes,4,opt,name=type,proto3" json:"type,omitempty"`
Publish *wrapperspb.BoolValue `protobuf:"bytes,5,opt,name=publish,proto3" json:"publish,omitempty"`
Protocol *wrapperspb.StringValue `protobuf:"bytes,6,opt,name=protocol,proto3" json:"protocol,omitempty"`
Labels map[string]string `` /* 139-byte string literal not displayed */
Geoip []string `protobuf:"bytes,8,rep,name=geoip,proto3" json:"geoip,omitempty"`
TrustedIps []string `protobuf:"bytes,9,rep,name=trusted_ips,json=trustedIps,proto3" json:"trusted_ips,omitempty"`
// Deprecated: Marked as deprecated in pb/rstream.proto.
Host *wrapperspb.StringValue `protobuf:"bytes,10,opt,name=host,proto3" json:"host,omitempty"`
TlsMode *wrapperspb.StringValue `protobuf:"bytes,11,opt,name=tls_mode,json=tlsMode,proto3" json:"tls_mode,omitempty"`
TlsAlpns []string `protobuf:"bytes,12,rep,name=tls_alpns,json=tlsAlpns,proto3" json:"tls_alpns,omitempty"`
TlsMinVersion *wrapperspb.StringValue `protobuf:"bytes,13,opt,name=tls_min_version,json=tlsMinVersion,proto3" json:"tls_min_version,omitempty"`
TlsCiphers []string `protobuf:"bytes,14,rep,name=tls_ciphers,json=tlsCiphers,proto3" json:"tls_ciphers,omitempty"`
MtlsAuth *wrapperspb.BoolValue `protobuf:"bytes,15,opt,name=mtls_auth,json=mtlsAuth,proto3" json:"mtls_auth,omitempty"`
// Deprecated: Marked as deprecated in pb/rstream.proto.
MtlsCacertPem *wrapperspb.StringValue `protobuf:"bytes,16,opt,name=mtls_cacert_pem,json=mtlsCacertPem,proto3" json:"mtls_cacert_pem,omitempty"`
HttpVersion *wrapperspb.StringValue `protobuf:"bytes,17,opt,name=http_version,json=httpVersion,proto3" json:"http_version,omitempty"`
// Deprecated: Marked as deprecated in pb/rstream.proto.
HttpUseTls *wrapperspb.BoolValue `protobuf:"bytes,18,opt,name=http_use_tls,json=httpUseTls,proto3" json:"http_use_tls,omitempty"`
TokenAuth *wrapperspb.BoolValue `protobuf:"bytes,19,opt,name=token_auth,json=tokenAuth,proto3" json:"token_auth,omitempty"`
RstreamAuth *wrapperspb.BoolValue `protobuf:"bytes,20,opt,name=rstream_auth,json=rstreamAuth,proto3" json:"rstream_auth,omitempty"`
ChallengeMode *wrapperspb.BoolValue `protobuf:"bytes,21,opt,name=challenge_mode,json=challengeMode,proto3" json:"challenge_mode,omitempty"`
Hostname *wrapperspb.StringValue `protobuf:"bytes,22,opt,name=hostname,proto3" json:"hostname,omitempty"`
Port *wrapperspb.UInt32Value `protobuf:"bytes,23,opt,name=port,proto3" json:"port,omitempty"`
UpstreamTls *wrapperspb.BoolValue `protobuf:"bytes,24,opt,name=upstream_tls,json=upstreamTls,proto3" json:"upstream_tls,omitempty"`
// contains filtered or unexported fields
}
func (*TunnelProperties) Descriptor
deprecated
func (*TunnelProperties) Descriptor() ([]byte, []int)
Deprecated: Use TunnelProperties.ProtoReflect.Descriptor instead.
func (*TunnelProperties) GetChallengeMode ¶ added in v1.3.0
func (x *TunnelProperties) GetChallengeMode() *wrapperspb.BoolValue
func (*TunnelProperties) GetCreationDate ¶
func (x *TunnelProperties) GetCreationDate() *timestamppb.Timestamp
func (*TunnelProperties) GetGeoip ¶
func (x *TunnelProperties) GetGeoip() []string
func (*TunnelProperties) GetHost
deprecated
added in
v1.3.0
func (x *TunnelProperties) GetHost() *wrapperspb.StringValue
Deprecated: Marked as deprecated in pb/rstream.proto.
func (*TunnelProperties) GetHostname ¶ added in v1.13.0
func (x *TunnelProperties) GetHostname() *wrapperspb.StringValue
func (*TunnelProperties) GetHttpUseTls
deprecated
func (x *TunnelProperties) GetHttpUseTls() *wrapperspb.BoolValue
Deprecated: Marked as deprecated in pb/rstream.proto.
func (*TunnelProperties) GetHttpVersion ¶
func (x *TunnelProperties) GetHttpVersion() *wrapperspb.StringValue
func (*TunnelProperties) GetId ¶
func (x *TunnelProperties) GetId() *wrapperspb.StringValue
func (*TunnelProperties) GetLabels ¶
func (x *TunnelProperties) GetLabels() map[string]string
func (*TunnelProperties) GetMtlsAuth ¶ added in v1.15.0
func (x *TunnelProperties) GetMtlsAuth() *wrapperspb.BoolValue
func (*TunnelProperties) GetMtlsCacertPem
deprecated
func (x *TunnelProperties) GetMtlsCacertPem() *wrapperspb.StringValue
Deprecated: Marked as deprecated in pb/rstream.proto.
func (*TunnelProperties) GetName ¶
func (x *TunnelProperties) GetName() *wrapperspb.StringValue
func (*TunnelProperties) GetPort ¶ added in v1.13.0
func (x *TunnelProperties) GetPort() *wrapperspb.UInt32Value
func (*TunnelProperties) GetProtocol ¶
func (x *TunnelProperties) GetProtocol() *wrapperspb.StringValue
func (*TunnelProperties) GetPublish ¶
func (x *TunnelProperties) GetPublish() *wrapperspb.BoolValue
func (*TunnelProperties) GetRstreamAuth ¶ added in v1.3.0
func (x *TunnelProperties) GetRstreamAuth() *wrapperspb.BoolValue
func (*TunnelProperties) GetTlsAlpns ¶
func (x *TunnelProperties) GetTlsAlpns() []string
func (*TunnelProperties) GetTlsCiphers ¶
func (x *TunnelProperties) GetTlsCiphers() []string
func (*TunnelProperties) GetTlsMinVersion ¶
func (x *TunnelProperties) GetTlsMinVersion() *wrapperspb.StringValue
func (*TunnelProperties) GetTlsMode ¶
func (x *TunnelProperties) GetTlsMode() *wrapperspb.StringValue
func (*TunnelProperties) GetTokenAuth ¶
func (x *TunnelProperties) GetTokenAuth() *wrapperspb.BoolValue
func (*TunnelProperties) GetTrustedIps ¶
func (x *TunnelProperties) GetTrustedIps() []string
func (*TunnelProperties) GetType ¶ added in v1.3.0
func (x *TunnelProperties) GetType() *wrapperspb.StringValue
func (*TunnelProperties) GetUpstreamTls ¶ added in v1.13.0
func (x *TunnelProperties) GetUpstreamTls() *wrapperspb.BoolValue
func (*TunnelProperties) ProtoMessage ¶
func (*TunnelProperties) ProtoMessage()
func (*TunnelProperties) ProtoReflect ¶
func (x *TunnelProperties) ProtoReflect() protoreflect.Message
func (*TunnelProperties) Reset ¶
func (x *TunnelProperties) Reset()
func (*TunnelProperties) String ¶
func (x *TunnelProperties) String() string